==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/CallbackregistrationRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;

import java.lang.Object;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Callbackregistration;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class CallbackregistrationRequest extends EntityRequest<Callbackregistration> {

    public CallbackregistrationRequest(ContextPath contextPath, Optional<Object> value) {
        super(Callbackregistration.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SystemuserRequest callbackregistration_modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("callbackregistration_modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest callbackregistration_modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("callbackregistration_modifiedby"), Optional.empty());
    }

    public SystemuserRequest callbackregistration_createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("callbackregistration_createdonbehalfby"), Optional.empty());
    }

    public SystemuserRequest callbackregistration_createdby() {
        return new SystemuserRequest(contextPath.addSegment("callbackregistration_createdby"), Optional.empty());
    }

    public BusinessunitRequest owningbusinessunit() {
        return new BusinessunitRequest(contextPath.addSegment("owningbusinessunit"), Optional.empty());
    }

    public PrincipalRequest ownerid() {
        return new PrincipalRequest(contextPath.addSegment("ownerid"), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.45-sources.jar: microsoft/dynamics/crm/entity/request/CallbackregistrationRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;

import java.lang.Object;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Callbackregistration;

@JsonIgnoreType
public class CallbackregistrationRequest extends EntityRequest<Callbackregistration> {

    public CallbackregistrationRequest(ContextPath contextPath, Optional<Object> value) {
        super(Callbackregistration.class, contextPath, value);
    }

    public SystemuserRequest callbackregistration_modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("callbackregistration_modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest callbackregistration_modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("callbackregistration_modifiedby"), Optional.empty());
    }

    public SystemuserRequest callbackregistration_createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("callbackregistration_createdonbehalfby"), Optional.empty());
    }

    public SystemuserRequest callbackregistration_createdby() {
        return new SystemuserRequest(contextPath.addSegment("callbackregistration_createdby"), Optional.empty());
    }

    public BusinessunitRequest owningbusinessunit() {
        return new BusinessunitRequest(contextPath.addSegment("owningbusinessunit"), Optional.empty());
    }

    public PrincipalRequest ownerid() {
        return new PrincipalRequest(contextPath.addSegment("ownerid"), Optional.empty());
    }

}
